import 'package:firebase_core/firebase_core.dart' as firebase;
import 'package:firebase_database/firebase_database.dart';
import 'package:jt_firebase_flutter/src/reference.dart';
import 'package:meta/meta.dart';
import 'package:jt_firebase_flutter/jt_firebase_flutter.dart';

/// Entry-point for JtDatabaseFlutter
class JtDatabaseFlutter implements FireblendDatabase {
  FirebaseDatabase _db;

  JtDatabaseFlutter({@required firebase.FirebaseApp app, String databaseURL}) {
    this._db = FirebaseDatabase(app: app, databaseURL: databaseURL);
  }

  JtDatabaseFlutter._(this._db);

  /// Get instance of JtDatabaseFlutter with specified databaseURL
  /// for default Firebase app.
  factory JtDatabaseFlutter.fromURL(String databaseURL) {
    return JtDatabaseFlutter(
        app: firebase.FirebaseApp.instance, databaseURL: databaseURL);
  }

  /// Get instance of JtDatabaseFlutter for default Firebase app.
  static JtDatabaseFlutter get instance =>
      JtDatabaseFlutter._(FirebaseDatabase.instance);

  /// Get instance of JtDatabaseFlutter for configured Firebase app.
  static Future<JtDatabaseFlutter> configure(
      {String appName = 'jt_database',
      @required firebase.FirebaseOptions options}) async {
    return JtDatabaseFlutter(
        app: await firebase.FirebaseApp.configure(
            name: appName, options: options),
        databaseURL: options.databaseURL);
  }

  FirebaseApp get app => this._db.app;

  String get databaseURL => this._db.databaseURL;

  @override
  JtDbReferenceFlutter ref([String path]) {
    return JtDbReferenceFlutter(this._db.reference().child(path));
  }

  @override
  Future<void> goOffline() {
    return this._db.goOffline();
  }

  @override
  Future<void> goOnline() {
    return this._db.goOnline();
  }
}
