import 'package:flutter_test/flutter_test.dart';
import 'package:jt_firebase_flutter/jt_firebase_flutter.dart';

void main() {
  group('database', () {
    JtDatabaseFlutter db;
    final path = 't-subjects';
    final child = '-my-custom-id';
    final data = {'01': 'test data', '02': 'data-02', '03': 'data-03'};

    TestWidgetsFlutterBinding.ensureInitialized();

    test('[TEST] JtDatabaseFlutter.fromURL', () async {
      db = JtDatabaseFlutter.fromURL('http://quizell-f89b3.firebaseio:9000');
      expect(db.runtimeType, JtDatabaseFlutter);
    });

    test('[TEST] .remove()', () async {
      assert(db != null, 'App must be initialized!');

      Exception error;
      await db.ref(path).remove().catchError((err) => error = err);

      expect(error, null);
    });

    test('[TEST] .push()', () async {
      assert(db != null, 'App must be initialized!');

      Exception error;
      await db.ref(path).push(data).catchError((err) => error = err);
      final snap = await db.ref(path).once();

      expect(error, null);
      expect(snap.runtimeType, JtDataSnapshotFlutter);
    });

    test('[TEST] .once()', () async {
      assert(db != null, 'App must be initialized!');

      final snap = await db.ref(path).once();

      expect(snap.runtimeType, JtDataSnapshotFlutter);
      expect(snap.key.length, 10);
      expect((snap.value as Map).values.length, 1);
      expect((snap.value as Map).values.first.length, data.length);
      expect((snap.value as Map).values.first, data);
    });

    test('[TEST] .set()', () async {
      assert(db != null, 'App must be initialized!');

      Exception error;
      await db.ref(path).child(child).set(data).catchError((err) {
        print(err);
        error = err;
      });

      expect(error, null);
    });

    test('[TEST] .child(\'$child\').once()', () async {
      assert(db != null, 'App must be initialized!');

      final snap = await db.ref(path).child(child).once();

      expect(snap.runtimeType, JtDataSnapshotFlutter);
      expect(snap.key, child);
      expect((snap.value as Map).values.length, 3);
    });
  });
}
